@@ -32,7 +32,7 @@ EVE_CATEGORY_ID_STRUCTURE = 65
 def load_eve_object(
     model_name: str, id: int, include_children=False, wait_for_children=True
 ) -> None:
-    """Task for loading an eve object. 
+    """Task for loading an eve object.
     Will only be created from ESI if it does not exist
     """
     ModelClass = EveUniverseEntityModel.get_model_class(model_name)
@@ -48,7 +48,9 @@ def update_or_create_eve_object(
     """Task for updating or creating an eve object from ESI"""
     ModelClass = EveUniverseEntityModel.get_model_class(model_name)
     ModelClass.objects.update_or_create_esi(
-        id=id, include_children=include_children, wait_for_children=wait_for_children,
+        id=id,
+        include_children=include_children,
+        wait_for_children=wait_for_children,
     )
 
 
